/*  gnutrition - a nutrition and diet analysis program.
 *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <gnome.h>

void
on_new_file1_activate    (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_exit1_activate        (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_add_food1_activate    (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_edit_food1_activate   (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_delete_food1_activate (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_pref1_activate        (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_about1_activate       (GtkMenuItem     *menuitem,
            gpointer         user_data);

gint 
on_idle_in_main          (gpointer         user_data);

void
on_mw_delete_released    (GtkButton       *button,
            gpointer         user_data);

void
on_mw_fd_clist_select_row(GtkCList        *clist,
            gint             row,
            gint             column,
            GdkEvent        *event,
            gpointer         user_data);

void
on_manual1_activate      (GtkMenuItem     *menuitem,
            gpointer         user_data);

void
on_nserv_msgbox_clicked  (GnomeDialog     *gnomedialog,
            gint             arg1,
            gpointer         user_data);

void
on_mw_new_button_enter   (GtkButton       *button,
            gpointer         user_data);

void
on_mw_open_button_enter  (GtkButton       *button,
            gpointer         user_data);

void
on_mw_save_button_enter  (GtkButton       *button,
            gpointer         user_data);

void
on_add_button_enter      (GtkButton       *button,
            gpointer         user_data);

void
on_delete_button_enter   (GtkButton       *button,
            gpointer         user_data);

void
on_edit_button_enter     (GtkButton       *button,
            gpointer         user_data);

void
on_nutr_goal_button_enter(GtkButton       *button,
            gpointer         user_data);

void
on_mw_new_button_leave   (GtkButton       *button,
            gpointer         user_data);

void
on_mw_open_button_leave  (GtkButton       *button,
            gpointer         user_data);

void
on_mw_save_button_leave  (GtkButton       *button,
            gpointer         user_data);

void
on_add_button_leave      (GtkButton       *button,
            gpointer         user_data);

void
on_delete_button_leave   (GtkButton       *button,
            gpointer         user_data);

void
on_edit_button_leave     (GtkButton       *button,
            gpointer         user_data);

void
on_nutr_comp_button_enter(GtkButton       *button,
            gpointer         user_data);

void
on_nutr_comp_button_leave(GtkButton       *button,
            gpointer         user_data);

void
on_nutr_goal_button_leave(GtkButton       *button,
            gpointer         user_data);

void
on_new_file1_activate(GtkMenuItem     *menuitem,
		    gpointer         user_data);

GladeXML*
gnutr_ret_xml( void);

GList*
gnutr_ret_food_glist( void);

void
gnutr_free_recipe( void);
